@@ -26,17 +26,10 @@ use warnings;
 
 use Carp;
 
-my $DumpModule;
-
-BEGIN {
-    # prefer YAML::Tiny as its smaller and all we really need
-    eval 'require YAML::Tiny';
-    $DumpModule = $@ ? 'Data::Dumper' : 'YAML::Tiny';
-}
-
 use File::Temp;
+use Shell::GetEnv::Dumper;
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 
 # a compendium of shells
@@ -48,6 +41,12 @@ my %shells = (
 		       Echo      => 'x',
 		      },
 
+	      dash => {
+		       Interactive     => 'i',
+		       Verbose   => 'v',
+		       Echo      => 'x',
+		      },
+
 	      sh => {
 		     Interactive     => 'i',
 		     Verbose   => 'v',
@@ -81,7 +80,7 @@ my %Opts = ( Startup => 1,
 	     Debug => 0,
 	     Echo    => 0,
 	     Verbose => 0,
-	     Interactive => 1,
+	     Interactive => 0,
 	     Redirect => 1,
 	     STDERR  => undef,
 	     STDOUT  => undef,
@@ -178,12 +177,11 @@ sub _dumper_script
 {
     my ( $self, $filename ) = @_;
 
-    my $dumpscript;
-
-    return 'YAML::Tiny' eq $DumpModule 
-      ? sprintf( q{%s -MYAML::Tiny=DumpFile -e 'DumpFile( "%s", \%%ENV)'}, $^X, $filename )
-      : sprintf( q{%s -MData::Dumper -e 'open(F,">","%s")||exit(1);print F Data::Dumper->Dump([\%%ENV],["ENV"])'},
-		 $^X, $filename );
+    # this invokes the module directly, using the Perl which was
+    # used to invoke the parent process.  It uses the fact that we
+    # use()'d Shell::GetEnv::Dumper and Perl stored the absolute path
+    # to it in %INC;
+    return qq{$^X '$INC{'Shell/GetEnv/Dumper.pm'}' $filename};
 }
 
 
@@ -241,15 +239,19 @@ sub _shell_options
 	  qw( NoStartup Echo Verbose Interactive )
 	    ;
 
-    # bundled options are those without the leading hyphen
-    my @bundled = grep{ ! /^-/ } @options;
+    # bundled options are those without a leading hyphen or plus
+    my %options = map { ( $_ => 1 ) } @options;
+    my @bundled = grep{ ! /^[-+]/ } keys %options;
+    delete @options{@bundled};
+
     my $bundled = @bundled ? '-' . join( '', @bundled ) : undef;
 
     # long options; bash treats these differently
-    my @longopts = grep{ /^--/ } @options;
+    my @longopts = grep{ /^--/ } keys %options;
+    delete @options{@longopts};
 
     # everything else
-    my @otheropts = grep { /^-[^-]/ } @options;
+    my @otheropts = keys %options;
 
     $self->{ShellOptions} =
 			[ 
@@ -298,23 +300,7 @@ sub _retrieve_env
 {
     my ( $self, $filename ) = @_;
 
-    if ( 'YAML::Tiny' eq $DumpModule )
-    {
-	( $self->{envs} ) = YAML::Tiny::LoadFile( $filename );
-    }
-
-    else
-    {
-	require IO::File;
-	my $fh = new IO::File $filename, 'r'
-	  or croak( __PACKAGE__, ": unable to open env file: $filename" );
-
-	# suck in the entire file as one line.
-	local $/;
-	my $res = <$fh>;
-	$self->{envs} = eval { eval $res; };
-	croak $@ if $@;
-    }
+    $self->{envs} = Shell::GetEnv::Dumper::read_envs( $filename );
 }
 
 # return variables
@@ -502,7 +488,9 @@ returned either as a hash or as a string suitable for use with the
 
 =head1 METHODS
 
-=over new
+=over
+
+=item new
 
   $env = Shell::GetEnv->new( $shell, @cmds, \%attrs );
 
@@ -539,7 +527,9 @@ B<STDOUT> attribute is used.  It defaults to I<false>.
 
 =item Interactive I<boolean>
 
-If true, put the shell in interactive mode.  It defaults to I<true>.
+If true, put the shell in interactive mode. Some shells do not react
+well when put in interactive mode but not connected to terminals.
+Try using the B<Expect> option instead. This defaults to I<false>.
 
 =item Redirect I<boolean>
 
